# TimeSlicedTcbNetMetricsType

Indicates whether this metrics is for a regular charge or a discount charge.

## Enum

* `REGULAR` (value: `'Regular'`)

* `DISCOUNT` (value: `'Discount'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


